@@ -11,3 +11,5 @@ from .uno import uno as uno_v0
 from .dou_dizhu import dou_dizhu as dou_dizhu_v0
 from .gin_rummy import gin_rummy as gin_rummy_v0
 from .go import go_env as go_v0
+from .hanabi import hanabi as hanabi_v0
+from .backgammon import backgammon_env as backgammon_v0
