@@ -32,7 +32,7 @@ class raw_env(AECEnv):
         self._agent_selector = agent_selector(self.agent_order)
 
         self.action_spaces = {name: spaces.Discrete(8 * 8 * 73) for name in self.agents}
-        self.observation_spaces = {name: spaces.Box(low=0, high=1, shape=(8, 8, 20), dtype=np.float32) for name in self.agents}
+        self.observation_spaces = {name: spaces.Box(low=0, high=1, shape=(8, 8, 20), dtype=np.bool) for name in self.agents}
 
         self.rewards = None
         self.dones = None
