@@ -11,7 +11,8 @@ def env(**kwargs):
     env = raw_env(**kwargs)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
+    pass_move = 308
+    env = wrappers.NanNoOpWrapper(env, pass_move, "passing turn with action number {}".format(pass_move))
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -48,7 +49,7 @@ class raw_env(AECEnv):
 
     def observe(self, agent):
         obs = self.env.get_state(self._name_to_int(agent))
-        return obs['obs']
+        return obs['obs'].astype(np.bool)
 
     def step(self, action, observe=True):
         assert action in self.infos[self.agent_selection]['legal_moves'], "Action is not part of legal moves."
@@ -62,7 +63,7 @@ class raw_env(AECEnv):
             self.infos[self._int_to_name(next_player_id)]['legal_moves'] = obs['legal_actions']
         self.agent_selection = self._agent_selector.next()
         if observe:
-            return obs['obs'] if obs else self._last_obs
+            return obs['obs'].astype(np.bool) if obs else self._last_obs.astype(np.bool)
 
     def reset(self, observe=True):
         self.has_reset = True
@@ -74,7 +75,7 @@ class raw_env(AECEnv):
         self.infos[self._int_to_name(player_id)]['legal_moves'] = obs['legal_actions']
         self._last_obs = obs['obs']
         if observe:
-            return obs['obs']
+            return obs['obs'].astype(np.bool)
         else:
             return
 
