@@ -102,9 +102,13 @@ class raw_env(AECEnv):
             from hanabi_learning_environment.rl_env import HanabiEnv, make
 
         except ModuleNotFoundError:
-            print("Hanabi is not installed."
-                  + "Run ´pip3 install hanabi_learning_environment´ from within your project environment."
-                  + "Consult hanabi/README.md for detailed information.")
+            raise ImportError(
+                (
+                    "Hanabi is not installed.\n",
+                    "Run ´pip3 install hanabi_learning_environment´ from within your project environment.\n",
+                    "Consult hanabi/README.md for detailed information."
+                )
+            )
 
         else:
 
@@ -241,7 +245,7 @@ class raw_env(AECEnv):
         agent_on_turn = self.agent_selection
 
         if action not in self.legal_moves:
-            raise ValueError(f'Illegal action. Please choose between legal actions, as documented in dict self.infos')
+            raise ValueError('Illegal action. Please choose between legal actions, as documented in dict self.infos')
 
         else:
             # Iterate agent_selection
@@ -260,7 +264,6 @@ class raw_env(AECEnv):
     def observe(self, agent_name: str):
         return np.array(self.infos[agent_name]['observations_vectorized'], np.float32)
 
-
     def _process_latest_observations(self, obs: Dict, reward: Optional[float] = 0, done: Optional[bool] = False):
         """Updates internal state"""
 
@@ -270,94 +273,24 @@ class raw_env(AECEnv):
 
         # Here we have to deal with the player index with offset = 1
         self.infos = {player_name: dict(
-                legal_moves=self.latest_observations['player_observations'][int(player_name[-1])]['legal_moves_as_int'],
-                legal_moves_as_dict=self.latest_observations['player_observations'][int(player_name[-1])]['legal_moves'],
-                observations_vectorized=self.latest_observations['player_observations'][int(player_name[-1])]['vectorized'],
-                observations=self.latest_observations['player_observations'][int(player_name[-1])])
-              for player_name in self.agents}
+            legal_moves=self.latest_observations['player_observations'][int(player_name[-1])]['legal_moves_as_int'],
+            legal_moves_as_dict=self.latest_observations['player_observations'][int(player_name[-1])]['legal_moves'],
+            observations_vectorized=self.latest_observations['player_observations'][int(player_name[-1])]['vectorized'],
+            observations=self.latest_observations['player_observations'][int(player_name[-1])])
+            for player_name in self.agents}
 
     def render(self, mode='human'):
-        """ Supports console print only. Prints the whole status dictionary.
+        """ Supports console print only. Prints player's data.
 
          Example:
-                     {'current_player': 0,
-         'player_observations': [{'current_player': 0,
-                            'current_player_offset': 0,
-                            'deck_size': 40,
-                            'discard_pile': [],
-                            'fireworks': {'B': 0,
-                                      'G': 0,
-                                      'R': 0,
-                                      'W': 0,
-                                      'Y': 0},
-                            'information_tokens': 8,
-                            'legal_moves': [{'action_type': 'PLAY',
-                                         'card_index': 0},
-                                        {'action_type': 'PLAY',
-                                         'card_index': 1},
-                                        {'action_type': 'PLAY',
-                                         'card_index': 2},
-                                        {'action_type': 'PLAY',
-                                         'card_index': 3},
-                                        {'action_type': 'PLAY',
-                                         'card_index': 4},
-                                        {'action_type': 'REVEAL_COLOR',
-                                         'color': 'R',
-                                         'target_offset': 1},
-                                        {'action_type': 'REVEAL_COLOR',
-                                         'color': 'G',
-                                         'target_offset': 1},
-                                        {'action_type': 'REVEAL_COLOR',
-                                         'color': 'B',
-                                         'target_offset': 1},
-                                        {'action_type': 'REVEAL_RANK',
-                                         'rank': 0,
-                                         'target_offset': 1},
-                                        {'action_type': 'REVEAL_RANK',
-                                         'rank': 1,
-                                         'target_offset': 1},
-                                        {'action_type': 'REVEAL_RANK',
-                                         'rank': 2,
-                                         'target_offset': 1}],
-                            'life_tokens': 3,
-                            'observed_hands': [[{'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1}],
-                                           [{'color': 'G', 'rank': 2},
-                                            {'color': 'R', 'rank': 0},
-                                            {'color': 'R', 'rank': 1},
-                                            {'color': 'B', 'rank': 0},
-                                            {'color': 'R', 'rank': 1}]],
-                            'num_players': 2,
-                            'vectorized': [ 0, 0, 1, ... ]},
-                           {'current_player': 0,
-                            'current_player_offset': 1,
-                            'deck_size': 40,
-                            'discard_pile': [],
-                            'fireworks': {'B': 0,
-                                      'G': 0,
-                                      'R': 0,
-                                      'W': 0,
-                                      'Y': 0},
-                            'information_tokens': 8,
-                            'legal_moves': [],
-                            'life_tokens': 3,
-                            'observed_hands': [[{'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1},
-                                            {'color': None, 'rank': -1}],
-                                           [{'color': 'W', 'rank': 2},
-                                            {'color': 'Y', 'rank': 4},
-                                            {'color': 'Y', 'rank': 2},
-                                            {'color': 'G', 'rank': 0},
-                                            {'color': 'W', 'rank': 1}]],
-                            'num_players': 2,
-                            'vectorized': [ 0, 0, 1, ... ]}]}
         """
-        print(self.latest_observations)
+        player_data = self.latest_observations['player_observations']
+        print("Active player:", self.agent_order[player_data[0]['current_player_offset']])
+        for i, d in enumerate(player_data):
+            print(self.agent_order[i])
+            print("========")
+            print(d['pyhanabi'])
+            print()
 
     def close(self):
         pass
