@@ -12,7 +12,8 @@ def env(**kwargs):
     env = raw_env(**kwargs)
     env = wrappers.TerminateIllegalWrapper(env, illegal_reward=-1)
     env = wrappers.AssertOutOfBoundsWrapper(env)
-    env = wrappers.NaNRandomWrapper(env)
+    pass_action = 3
+    env = wrappers.NanNoOpWrapper(env, pass_action, "'checked' with action {}".format(pass_action))
     env = wrappers.OrderEnforcingWrapper(env)
     return env
 
@@ -31,7 +32,7 @@ class raw_env(AECEnv):
         self.num_agents = len(self.agents)
         self.has_reset = False
 
-        self.observation_spaces = self._convert_to_dict([spaces.Box(low=0.0, high=1.0, shape=(36,), dtype=np.bool) for _ in range(self.num_agents)])
+        self.observation_spaces = self._convert_to_dict([spaces.Box(low=0.0, high=1.0, shape=(36,), dtype=np.float64) for _ in range(self.num_agents)])
         self.action_spaces = self._convert_to_dict([spaces.Discrete(self.env.game.get_action_num()) for _ in range(self.num_agents)])
         self.agent_order = self.agents
         self._agent_selector = agent_selector(self.agent_order)
