@@ -7,7 +7,6 @@ import pymunk
 import pymunk.pygame_util
 import math
 import numpy as np
-from skimage import measure
 import gym
 from gym.utils import seeding
 from pettingzoo import AECEnv
@@ -295,7 +294,6 @@ class raw_env(AECEnv):
 
         self.dones = dict(zip(self.agents, [self.done for _ in self.agents]))
         self.agent_selection = self._agent_selector.next()
-        pygame.event.pump()
         if observe:
             return self.observe(self.agent_selection)
 
