@@ -4,16 +4,17 @@ SCREEN_SIZE = SCREEN_WIDTH, SCREEN_HEIGHT = (1280, 720)
 BACKGROUND_COLOR = (217, 151, 106)
 FPS = 15
 
-# FENCE_WIDTH = 100
 FENCE_WIDTH = 22
 WATER_HEIGHT = 100
 
-# AGENT_RADIUS = 16.5
 AGENT_RADIUS = 15
 AGENT_DIAMETER = AGENT_RADIUS * 2
 # The 3 is for RBG values
-OBSERVATION_SIDE_LENGTH = 5 * AGENT_DIAMETER
-OBSERVATION_SHAPE = (OBSERVATION_SIDE_LENGTH, OBSERVATION_SIDE_LENGTH, 3)
+PROSPEC_OBSERV_SIDE_LEN = 5 * AGENT_DIAMETER
+PROSPEC_OBSERV_SHAPE = (PROSPEC_OBSERV_SIDE_LEN, PROSPEC_OBSERV_SIDE_LEN, 3)
+# Slightly bigger for bankers - 2 integers bigger on each side
+BANKER_OBSERV_SIDE_LEN = PROSPEC_OBSERV_SIDE_LEN + 4
+BANKER_OBSERV_SHAPE = (BANKER_OBSERV_SIDE_LEN, BANKER_OBSERV_SIDE_LEN, 3)
 
 MAX_SPRITE_ROTATION = math.pi / 4
 
@@ -28,7 +29,6 @@ TWO_PI = math.pi * 2.0
 
 FENCE_COLLISION_BUFFER = AGENT_DIAMETER
 VERT_FENCE_HEIGHT = SCREEN_HEIGHT - WATER_HEIGHT
-# VERT_FENCE_WIDTH =
 
 # For the left and right fences
 FENCE_VERT_VERTICES = (
