@@ -77,5 +77,5 @@ class raw_env(AECEnv):
             return self.observe(self.agent_selection)
 
     def observe(self, agent):
-        o = np.array(self.env.safely_observe(self.agent_name_mapping[agent]))
+        o = np.array(self.env.safely_observe(self.agent_name_mapping[agent]), np.float32)
         return o
