@@ -1,16 +1,24 @@
 from .waterworld_base import MAWaterWorld as _env
 from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector
-from pettingzoo.utils import EnvLogger
+from pettingzoo.utils import wrappers
 import numpy as np
 
 
-class env(AECEnv):
+def env(**kwargs):
+    env = raw_env(**kwargs)
+    env = wrappers.ClipOutOfBoundsWrapper(env)
+    env = wrappers.NanZerosWrapper(env)
+    env = wrappers.OrderEnforcingWrapper(env)
+    return env
+
+
+class raw_env(AECEnv):
 
     metadata = {'render.modes': ['human']}
 
     def __init__(self, seed=None, *args, **kwargs):
-        super(env, self).__init__()
+        super().__init__()
         self.env = _env(seed, *args, **kwargs)
 
         self.num_agents = self.env.num_agents
@@ -42,27 +50,14 @@ class env(AECEnv):
             return self.observe(self.agent_selection)
 
     def close(self):
-        if not self.has_reset:
-            EnvLogger.warn_close_before_reset()
-        else:
+        if self.has_reset:
             self.env.close()
 
     def render(self, mode="human"):
-        if not self.has_reset:
-            EnvLogger.error_render_before_reset()
-        else:
-            self.env.render()
+        self.env.render()
 
     def step(self, action, observe=True):
-        if not self.has_reset:
-            EnvLogger.error_step_before_reset()
         agent = self.agent_selection
-        if action is None or any(np.isnan(action)):
-            EnvLogger.warn_action_is_NaN(backup_policy="setting to zeros")
-            action = np.zeros_like(self.action_spaces[agent].sample())
-        elif not self.action_spaces[agent].contains(action):
-            EnvLogger.warn_action_out_of_bound(action=action, action_space=self.action_spaces[agent], backup_policy="setting to zeros")
-            action = np.zeros_like(self.action_spaces[agent].sample())
 
         self.env.step(action, self.agent_name_mapping[agent], self._agent_selector.is_last())
         for r in self.rewards:
@@ -82,6 +77,4 @@ class env(AECEnv):
             return self.observe(self.agent_selection)
 
     def observe(self, agent):
-        if not self.has_reset:
-            EnvLogger.error_observe_before_reset()
         return self.env.observe(self.agent_name_mapping[agent])
