@@ -8,8 +8,10 @@ def bombardment_test(env, cycles=10000):
 
     prev_observe = env.reset()
     observation_0 = copy(prev_observe)
-    for _ in range(cycles):
-        for agent in env.agent_order:  # step through every agent once with observe=True
+    for i in range(cycles):
+        if i == cycles / 2:
+            print("\t50% through bombardment test")
+        for agent in env.agent_iter(env.num_agents):  # step through every agent once with observe=True
             if 'legal_moves' in env.infos[agent]:
                 action = random.choice(env.infos[agent]['legal_moves'])
             else:
@@ -18,7 +20,5 @@ def bombardment_test(env, cycles=10000):
             assert env.observation_spaces[agent].contains(prev_observe), "Agent's observation is outside of its observation space"
             test_observation(prev_observe, observation_0)
             prev_observe = next_observe
-            if all(env.dones.values()):
-                prev_observe = env.reset()
-                break
+        prev_observe = env.reset()
     print("Passed bombardment test")
