@@ -12,16 +12,15 @@ def performance_benchmark(env):
 
     while True:
         cycles += 1
-        for agent in env.agent_order:  # step through every agent once with observe=True
+        for agent in env.agent_iter(env.num_agents):  # step through every agent once with observe=True
             if 'legal_moves' in env.infos[agent]:
                 action = random.choice(env.infos[agent]['legal_moves'])
             else:
                 action = env.action_spaces[agent].sample()
             _ = env.step(action)
             turn += 1
-            if all(env.dones.values()):
-                _ = env.reset()
-                break
+        _ = env.reset()
+
         if time.time() - start > 5:
             end = time.time()
             break
