@@ -7,13 +7,11 @@ def test_render(env):
     env.reset(observe=False)
     for mode in render_modes:
         for _ in range(10):
-            for agent in env.agent_order:
+            for agent in env.agent_iter(env.num_agents):
                 if 'legal_moves' in env.infos[agent]:
                     action = random.choice(env.infos[agent]['legal_moves'])
                 else:
                     action = env.action_spaces[agent].sample()
                 env.step(action, observe=False)
                 env.render(mode=mode)
-                if all(env.dones.values()):
-                    env.reset()
-                    break
+            env.reset()
